function compcon(B,A,Rt,St,k)
% COMPCON compares the reduced order controllers obtained by COR 
%         instruction.
%
%	compcon(B,A,Rt,St,k)
%
%	B/A is the transfer function of the plant.
%	Rt and St are the matrices containing the coefficients of the
%	reduced order controllers. These matrices are generated by COR
%	instruction.
%	k is a vector containing the controller No. to be compared. zero
%  corresponds to the initial controller.
%	(i.e. k=[0,1,4] is used to compare the initial, the first (identified
%   with the same order) and the forth controller).
%   
%	The outputs of this function are the plots of three sensitivity
%	functions (Syp, Sup, Syb) together with the frequency response of 
%  the controller.
%
% June 30,1999
% Copyright by Adaptech, 1997-1999

if nargin<5, error('compcon(B,A,Rt,St,k)');end
k=k+1;
[n,m]=size(St);

tol=0.001;
w=logspace(-4,pi,round(1/tol));
z=exp(-j*w);
mt1=[];mt2=[];mt3=[];mt4=[];
txtlg=sprintf('legend(h,''controller no.%d'',',k(1)-1);
nk=length(k);
for i=1:nk,
   AS=conv(A,St(k(i),:));
   BR=conv(B,Rt(k(i),:));
   AR=conv(A,Rt(k(i),:));
   P=addz(AS,BR);
   PVP=polyval(P,z);
   m1=abs(polyval(AS,z)./PVP);
   m2=abs(polyval(AR,z)./PVP);
   m3=abs(polyval(BR,z)./PVP);
   m4=abs(polyval(Rt(k(i),:),z)./polyval(St(k(i),:),z));
   mt1=[mt1;m1];
   mt2=[mt2;m2];
   mt3=[mt3;m3];
   mt4=[mt4;m4];
   if((i>1)&(i<nk)) txtlg=sprintf('%s''controller no.%d'',',txtlg,k(i)-1);
   elseif(i==nk) txtlg=sprintf('%s''controller no.%d'',0);',txtlg,k(i)-1);
   end;
end
o=w/(2*pi);
mt1=20*log10(mt1);
mt2=20*log10(mt2);
mt3=20*log10(mt3);
mt4=20*log10(mt4);
figure(1)
hold on
%barmenu
h=plot(o,mt1);
eval(txtlg);
xlabel('Normalized Frequency f/fs');ylabel('dB');
title('Syp')
figure(2)
hold on
%barmenu
h=plot(o,mt2);
eval(txtlg);
xlabel('Normalized Frequency f/fs');ylabel('dB');
title('Sup')
figure(3)
hold on
%barmenu
h=plot(o,mt3);
eval(txtlg);
xlabel('Normalized Frequency f/fs');ylabel('dB');
title('Syb')
figure(4)
hold on
%barmenu
h=plot(o,mt4);
xlabel('Normalized Frequency f/fs');ylabel('dB');
eval(txtlg);
title('Controller')
