function [mag,f]=mbode(Num,Den,Ts)
% MBODE	plots the magnitude of the frequency response of a discrete time
%	transfer function.
%
%	[mag,f]=mbode(Num,Den,Ts)
%
%	Num: is a vector containing the numerator of a transfer function
%	     or a matrix in each row the numerator of a transfer function.	
%	Den: is a vector containing the denominator of a transfer function
%	     or a matrix in each row the denominator of a transfer function.
%	Ts: is the sampling period.
%
%	mag: is the magnitude of the frequency response
%	f: is the frequency in Hz
%
%	note: In the case Num and den are the matrices the magnitude of
%	      the frequency responces of different transfer function will 
%	      be ploted in the same figure (for the comparison purpose).
%
% June 30,1999
% Copyright by Adaptech, 1997-1999


if nargin<3, error('usage:[mag,f]=mbode(Num,Den,Ts)');end
[n1,n2]=size(Num);
[n3,n4]=size(Den);
if n1~=n3, error('Num and Den should have the same number of row');end
w=(1:250)*pi/250;
z=exp(-j*w);
mag=[];
txtlg=sprintf('legend(''TF%d'',',1);
for i=1:n1
	m=abs(polyval(Num(i,:),z)./polyval(Den(i,:),z));
	mag=[mag;20*log10(m)];
        if((i>1)&(i<n1)) txtlg=sprintf('%s''TF%d'',',txtlg,i);
        elseif(i==n1) txtlg=sprintf('%s''TF%d'',0);',txtlg,i);end
end

f=w/(2*pi*Ts);
figure
barmenu
plot(f,mag)
xlabel('Frequency in Hz');ylabel('dB');
if n1>1, eval(txtlg);end



