function b=smarg(B,A,R,S,tol)
%	smarge computes the stability margin of a discrete time SISO closed loop 
%			 system (the inverse of the infinity norm of four closed-loop sensitivity 
%		  	 functions)
%
%		    b=smarg(B,A,R,S,tol)
%
%     	 B and A are respectively the numerator and denominator of the plant model.
%			 R and s are respectively the numerator and denominator of a stabilizing
%			 controller.
%			 tol is the tolerance value (default=0.001)
%
% June 30,1999
% Copyright by Adaptech, 1997-1999

if nargin<4, error('usage: b=smarg(B,A,R,S,tol)');end
if nargin<5, tol=0.001;end

if length(A)>length(B), B=[B zeros(1,length(A)-length(B))];
else A=[A zeros(1,length(B)-length(A))];end

if length(S)>length(R), R=[R zeros(1,length(S)-length(R))];
else S=[S zeros(1,length(R)-length(S))];end

P=conv(A,S)+conv(B,R);

w=logspace(-4,pi,round(1/tol));
z=exp(-j*w);
S11=abs(polyval(conv(A,S),z)./polyval(P,z));
S12=abs(polyval(conv(B,S),z)./polyval(P,z));
S21=abs(polyval(conv(A,R),z)./polyval(P,z));
S22=abs(polyval(conv(B,R),z)./polyval(P,z));

n=length(S11);
for i=1:n, s=svd([S11(i) S12(i);S21(i) S22(i)]);sigma(i)=s(1);end
b=inv(max(sigma));

